Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6924)

Unified Diff: chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_bubble_view.h

Issue 2694893002: Integrate SMS service with Desktop iOS promotion (Closed)
Patch Set: nits Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_bubble_view.h
diff --git a/chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_view.h b/chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_bubble_view.h
similarity index 50%
rename from chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_view.h
rename to chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_bubble_view.h
index 65c71080090d20276317dc94031525047678e90a..51bbddcd034b8ea5ce2fe1ef82daa9ff802e6a77 100644
--- a/chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_view.h
+++ b/chrome/browser/ui/views/desktop_ios_promotion/desktop_ios_promotion_bubble_view.h
@@ -2,24 +2,34 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_VIEW_H_
-#define CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_VIEW_H_
+#ifndef CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_BUBBLE_VIEW_H_
+#define CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_BUBBLE_VIEW_H_
#include "base/macros.h"
#include "chrome/browser/ui/desktop_ios_promotion/desktop_ios_promotion_util.h"
+#include "chrome/browser/ui/desktop_ios_promotion/desktop_ios_promotion_view.h"
#include "ui/views/controls/button/button.h"
+#include "ui/views/controls/label.h"
#include "ui/views/view.h"
class DesktopIOSPromotionController;
+class Profile;
-// The DesktopIOSPromotionView has the basic layout for the
+// The DesktopIOSPromotionBubbleView has the basic layout for the
// desktop to ios promotion view.
// This view will always be created as a subview of an existing
// bubble (ie. Password Bubble, Bookmark Bubble).
-class DesktopIOSPromotionView : public views::View,
- public views::ButtonListener {
+class DesktopIOSPromotionBubbleView : public DesktopIOSPromotionView,
+ public views::View,
+ public views::ButtonListener {
public:
- explicit DesktopIOSPromotionView(desktop_ios_promotion::PromotionEntryPoint);
+ DesktopIOSPromotionBubbleView(
+ Profile* profile,
+ desktop_ios_promotion::PromotionEntryPoint entry_point);
+ ~DesktopIOSPromotionBubbleView() override;
+
+ // DesktopIOSPromotionView:
+ void UpdateRecoveryPhoneLabel() override;
private:
// ButtonListener:
@@ -27,11 +37,11 @@ class DesktopIOSPromotionView : public views::View,
views::Button* send_sms_button_ = nullptr;
views::Button* no_button_ = nullptr;
- // TODO(crbug.com/676655): Add learn more link.
+ views::Label* recovery_phone_label_ = nullptr;
- DesktopIOSPromotionController* promotion_controller_ = nullptr;
+ std::unique_ptr<DesktopIOSPromotionController> promotion_controller_;
- DISALLOW_COPY_AND_ASSIGN(DesktopIOSPromotionView);
+ DISALLOW_COPY_AND_ASSIGN(DesktopIOSPromotionBubbleView);
};
-#endif // CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_VIEW_H_
+#endif // CHROME_BROWSER_UI_VIEWS_DESKTOP_IOS_PROMOTION_DESKTOP_IOS_PROMOTION_BUBBLE_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698